@@ -1,5 +1,4 @@
 import os
-import shutil
 import tempfile
 
 from . import (
@@ -27,7 +26,7 @@ class TestGalaxyLibraries(GalaxyTestBase.GalaxyTestBase):
 
     def test_get_libraries(self):
         libraries_with_name = self.gi.libraries.get_libraries(name=self.name)
-        assert len([l for l in libraries_with_name if l["id"] == self.library["id"]]) == 1
+        assert len([lib for lib in libraries_with_name if lib["id"] == self.library["id"]]) == 1
 
         deleted_name = "deleted test library"
         deleted_library_id = self.gi.libraries.create_library(
@@ -35,19 +34,19 @@ class TestGalaxyLibraries(GalaxyTestBase.GalaxyTestBase):
         )["id"]
         self.gi.libraries.delete_library(deleted_library_id)
         deleted_libraries_with_name = self.gi.libraries.get_libraries(name=deleted_name, deleted=True)
-        assert len([l for l in deleted_libraries_with_name if l["id"] == deleted_library_id]) == 1
+        assert len([lib for lib in deleted_libraries_with_name if lib["id"] == deleted_library_id]) == 1
 
         all_non_deleted_libraries = self.gi.libraries.get_libraries(deleted=False)
-        assert len([l for l in all_non_deleted_libraries if l["id"] == self.library["id"]]) == 1
-        assert [l for l in all_non_deleted_libraries if l["id"] == deleted_library_id] == []
+        assert len([lib for lib in all_non_deleted_libraries if lib["id"] == self.library["id"]]) == 1
+        assert [lib for lib in all_non_deleted_libraries if lib["id"] == deleted_library_id] == []
 
         all_deleted_libraries = self.gi.libraries.get_libraries(deleted=True)
-        assert [l for l in all_deleted_libraries if l["id"] == self.library["id"]] == []
-        assert len([l for l in all_deleted_libraries if l["id"] == deleted_library_id]) == 1
+        assert [lib for lib in all_deleted_libraries if lib["id"] == self.library["id"]] == []
+        assert len([lib for lib in all_deleted_libraries if lib["id"] == deleted_library_id]) == 1
 
         all_libraries = self.gi.libraries.get_libraries(deleted=None)
-        assert len([l for l in all_libraries if l["id"] == self.library["id"]]) == 1
-        assert len([l for l in all_libraries if l["id"] == deleted_library_id]) == 1
+        assert len([lib for lib in all_libraries if lib["id"] == self.library["id"]]) == 1
+        assert len([lib for lib in all_libraries if lib["id"] == deleted_library_id]) == 1
 
     def test_show_library(self):
         library_data = self.gi.libraries.show_library(self.library["id"])
@@ -55,43 +54,51 @@ class TestGalaxyLibraries(GalaxyTestBase.GalaxyTestBase):
         assert self.library["name"] == library_data["name"]
 
     def test_upload_file_from_url(self):
-        self.gi.libraries.upload_file_from_url(
-            self.library["id"], "https://zenodo.org/record/582600/files/wildtype.fna?download=1"
-        )
+        url = "https://zenodo.org/record/582600/files/wildtype.fna?download=1"
+        ret = self.gi.libraries.upload_file_from_url(self.library["id"], url)
+        assert len(ret) == 1
+        ldda_dict = ret[0]
+        assert ldda_dict["name"] == url
 
     def test_upload_file_contents(self):
-        self.gi.libraries.upload_file_contents(self.library["id"], FOO_DATA)
+        ret = self.gi.libraries.upload_file_contents(self.library["id"], FOO_DATA)
+        assert len(ret) == 1
+        ldda_dict = ret[0]
+        assert ldda_dict["name"] == "Pasted Entry"
 
     def test_upload_file_from_local_path(self):
         with tempfile.NamedTemporaryFile(mode="w", prefix="bioblend_test_") as f:
             f.write(FOO_DATA)
             f.flush()
-            self.gi.libraries.upload_file_from_local_path(self.library["id"], f.name)
+            filename = f.name
+            ret = self.gi.libraries.upload_file_from_local_path(self.library["id"], filename)
+        assert len(ret) == 1
+        ldda_dict = ret[0]
+        assert ldda_dict["name"] == os.path.basename(filename)
 
-    def test_upload_file_from_server(self):
-        pass
+    # def test_upload_file_from_server(self):
+    #     pass
 
     def test_upload_from_galaxy_filesystem(self):
         bnames = [f"f{i}.txt" for i in range(2)]
-        tempdir = tempfile.mkdtemp(prefix="bioblend_test_")
-        try:
+        with tempfile.TemporaryDirectory() as tempdir:
             fnames = [os.path.join(tempdir, _) for _ in bnames]
             for fn in fnames:
                 with open(fn, "w") as f:
                     f.write(FOO_DATA)
             filesystem_paths = "\n".join(fnames)
             ret = self.gi.libraries.upload_from_galaxy_filesystem(self.library["id"], filesystem_paths)
-            for dataset_dict in ret:
+            for fn, dataset_dict in zip(fnames, ret):
                 dataset = self.gi.libraries.wait_for_dataset(self.library["id"], dataset_dict["id"])
                 assert dataset["state"] == "ok"
+                assert dataset["name"] == os.path.basename(fn)
             ret = self.gi.libraries.upload_from_galaxy_filesystem(
                 self.library["id"], filesystem_paths, link_data_only="link_to_files"
             )
-            for dataset_dict in ret:
+            for fn, dataset_dict in zip(fnames, ret):
                 dataset = self.gi.libraries.wait_for_dataset(self.library["id"], dataset_dict["id"])
                 assert dataset["state"] == "ok"
-        finally:
-            shutil.rmtree(tempdir)
+                assert dataset["name"] == os.path.basename(fn)
 
     def test_copy_from_dataset(self):
         history = self.gi.histories.create_history()
