@@ -178,7 +178,7 @@ class TestWrapper(unittest.TestCase):
         assert self.d["a"] == 1
         assert self.d["b"][0] == 2
         with pytest.raises(AttributeError):
-            self.w.foo  # type: ignore[attr-defined]
+            _ = self.w.foo  # type: ignore[attr-defined]
         with pytest.raises(AttributeError):
             self.w.foo = 0  # type: ignore[assignment]
 
@@ -502,7 +502,6 @@ class TestGalaxyInstance(GalaxyObjectsTestBase):
             wf = self.gi.workflows.import_new(f.read())
         self._check_and_del_workflow(wf)
 
-    @test_util.skip_unless_galaxy("release_19.01")
     def test_workflow_parameter_input(self):
         with open(SAMPLE_WF_PARAMETER_INPUT_FN) as f:
             self.gi.workflows.import_new(f.read())
