@@ -28,3 +28,12 @@ class TestGalaxyToolDependencies(GalaxyTestBase.GalaxyTestBase):
         assert isinstance(toolbox_summary_select_tool_ids, list)
         assert len(toolbox_summary_select_tool_ids) == 1
         assert toolbox_summary_select_tool_ids[0]["tool_ids"][0] == tool_id
+
+    @test_util.skip_unless_galaxy("release_20.01")
+    def test_unused_dependency_paths(self):
+        unused_paths = self.gi.tool_dependencies.unused_dependency_paths()
+        assert isinstance(unused_paths, list)
+
+    @test_util.skip_unless_galaxy("release_20.01")
+    def test_delete_unused_dependency_paths(self):
+        self.gi.tool_dependencies.delete_unused_dependency_paths(paths=[])
