@@ -6,11 +6,16 @@ the environment variable ``BIOBLEND_TEST_SUITE`` to ``quick``.
 """
 import os
 import sys
+from typing import (
+    List,
+    NoReturn,
+    Optional,
+)
 
 try:
     import pytest
 except ImportError:
-    pytest = None  # type: ignore
+    pytest = None
 
 DIRECTORY = os.path.abspath(os.path.dirname(__file__))
 BIOBLEND_TEST_SUITE = os.environ.get("BIOBLEND_TEST_SUITE", "full")
@@ -24,7 +29,7 @@ quick_tests = [
 ]
 
 
-def main(args=None):
+def main(args: Optional[List[str]] = None) -> NoReturn:
     """Entry point that delegates to pytest.main."""
     if pytest is None:
         raise Exception("pytest is required to use this script.")
