@@ -16,7 +16,6 @@ from typing import (
     TYPE_CHECKING,
     Union,
 )
-from urllib.parse import urljoin
 
 from requests import Response
 from typing_extensions import Literal
@@ -73,7 +72,7 @@ class DatasetClient(Client):
             if require_ok_state:
                 raise DatasetStateException(message)
             else:
-                warnings.warn(message, DatasetStateWarning)
+                warnings.warn(message, DatasetStateWarning, stacklevel=2)
 
         file_ext = dataset.get("file_ext")
         # Resort to 'data' when Galaxy returns an empty or temporary extension
@@ -86,7 +85,7 @@ class DatasetClient(Client):
         # does not work when using REMOTE_USER with access disabled to
         # everything but /api without auth
         download_url = dataset["download_url"] + "?to_ext=" + file_ext
-        url = urljoin(self.gi.base_url, download_url)
+        url = f"{self.gi.base_url}{download_url}"
 
         r = self.gi.make_get_request(url, stream=stream_content)
         r.raise_for_status()
@@ -453,7 +452,7 @@ class DatasetStateException(Exception):
     pass
 
 
-class DatasetStateWarning(Warning):
+class DatasetStateWarning(UserWarning):
     pass
 
 
