@@ -1,16 +1,28 @@
 """
 Contains possible interactions with the Galaxy Histories
 """
+from typing import (
+    Any,
+    Dict,
+    Optional,
+    TYPE_CHECKING,
+)
+
+from typing_extensions import Literal
+
 from bioblend.galaxy.client import Client
 
+if TYPE_CHECKING:
+    from bioblend.galaxy import GalaxyInstance
+
 
 class GenomeClient(Client):
-    module = 'genomes'
+    module = "genomes"
 
-    def __init__(self, galaxy_instance):
+    def __init__(self, galaxy_instance: "GalaxyInstance") -> None:
         super().__init__(galaxy_instance)
 
-    def get_genomes(self):
+    def get_genomes(self) -> list:
         """
         Returns a list of installed genomes
 
@@ -20,7 +32,14 @@ class GenomeClient(Client):
         genomes = self._get()
         return genomes
 
-    def show_genome(self, id, num=None, chrom=None, low=None, high=None):
+    def show_genome(
+        self,
+        id: str,
+        num: Optional[str] = None,
+        chrom: Optional[str] = None,
+        low: Optional[str] = None,
+        high: Optional[str] = None,
+    ) -> Dict[str, Any]:
         """
         Returns information about build <id>
 
@@ -42,23 +61,35 @@ class GenomeClient(Client):
         :rtype: dict
         :return: Information about the genome build
         """
-        params = {}
+        params: Dict[str, str] = {}
         if num:
-            params['num'] = num
+            params["num"] = num
         if chrom:
-            params['chrom'] = chrom
+            params["chrom"] = chrom
         if low:
-            params['low'] = low
+            params["low"] = low
         if high:
-            params['high'] = high
-        return self._get(id, params)
+            params["high"] = high
+        return self._get(id=id, params=params)
 
-    def install_genome(self, func='download', source=None, dbkey=None,
-                       ncbi_name=None, ensembl_dbkey=None, url_dbkey=None,
-                       indexers=None):
+    def install_genome(
+        self,
+        func: Literal["download", "index"] = "download",
+        source: Optional[str] = None,
+        dbkey: Optional[str] = None,
+        ncbi_name: Optional[str] = None,
+        ensembl_dbkey: Optional[str] = None,
+        url_dbkey: Optional[str] = None,
+        indexers: Optional[list] = None,
+    ) -> Dict[str, Any]:
         """
         Download and/or index a genome.
 
+        :type func: str
+        :param func: Allowed values: 'download', Download and index; 'index', Index only
+
+        :type source: str
+        :param source: Data source for this build. Can be: UCSC, Ensembl, NCBI, URL
 
         :type dbkey: str
         :param dbkey: DB key of the build to download, ignored unless 'UCSC' is specified as the source
@@ -72,33 +103,27 @@ class GenomeClient(Client):
         :type url_dbkey: str
         :param url_dbkey: DB key to use for this build, ignored unless URL is specified as the source
 
-        :type source: str
-        :param source: Data source for this build. Can be: UCSC, Ensembl, NCBI, URL
-
         :type indexers: list
         :param indexers: POST array of indexers to run after downloading (indexers[] = first, indexers[] = second, ...)
 
-        :type func: str
-        :param func: Allowed values: 'download', Download and index; 'index', Index only
-
         :rtype: dict
         :return: dict( status: 'ok', job: <job ID> )
                  If error:
                  dict( status: 'error', error: <error message> )
         """
-        payload = {}
+        payload: Dict[str, Any] = {}
         if source:
-            payload['source'] = source
+            payload["source"] = source
         if func:
-            payload['func'] = func
+            payload["func"] = func
         if dbkey:
-            payload['dbkey'] = dbkey
+            payload["dbkey"] = dbkey
         if ncbi_name:
-            payload['ncbi_name'] = ncbi_name
+            payload["ncbi_name"] = ncbi_name
         if ensembl_dbkey:
-            payload['ensembl_dbkey'] = ensembl_dbkey
+            payload["ensembl_dbkey"] = ensembl_dbkey
         if url_dbkey:
-            payload['url_dbkey'] = url_dbkey
+            payload["url_dbkey"] = url_dbkey
         if indexers:
-            payload['indexers'] = indexers
+            payload["indexers"] = indexers
         return self._post(payload)
