@@ -17,7 +17,6 @@ from typing import (
     Pattern,
     Union,
 )
-from urllib.parse import urljoin
 
 from typing_extensions import Literal
 
@@ -870,7 +869,7 @@ class HistoryClient(Client):
           any such tab is recommended.
         """
 
-        url = urljoin(self.gi.base_url, f"history/switch_to_history?hist_id={history_id}")
+        url = f"{self.gi.base_url}/history/switch_to_history?hist_id={history_id}"
         webbrowser.open_new_tab(url)
 
     def get_extra_files(self, history_id: str, dataset_id: str) -> List[str]:
@@ -886,9 +885,6 @@ class HistoryClient(Client):
 
         :rtype: list
         :return: List of extra files
-
-        .. note::
-          This method works only on Galaxy 19.01 or later.
         """
         url = "/".join((self._make_url(history_id, contents=True), dataset_id, "extra_files"))
         return self._get(url=url)
