@@ -4,7 +4,11 @@ Contains possible interactions with the Galaxy workflow invocations
 import logging
 import time
 from typing import (
+    Any,
+    Dict,
+    List,
     Optional,
+    TYPE_CHECKING,
 )
 
 from bioblend import (
@@ -12,22 +16,34 @@ from bioblend import (
     TimeoutException,
 )
 from bioblend.galaxy.client import Client
+from bioblend.galaxy.workflows import InputsBy
+
+if TYPE_CHECKING:
+    from bioblend.galaxy import GalaxyInstance
 
 log = logging.getLogger(__name__)
 
-INVOCATION_TERMINAL_STATES = {'cancelled', 'failed', 'scheduled'}
+INVOCATION_TERMINAL_STATES = {"cancelled", "failed", "scheduled"}
 # Invocation non-terminal states are: 'new', 'ready'
 
 
 class InvocationClient(Client):
-    module = 'invocations'
+    gi: "GalaxyInstance"
+    module = "invocations"
 
-    def __init__(self, galaxy_instance):
+    def __init__(self, galaxy_instance: "GalaxyInstance") -> None:
         super().__init__(galaxy_instance)
 
-    def get_invocations(self, workflow_id=None, history_id=None, user_id=None,
-                        include_terminal=True, limit=None, view='collection',
-                        step_details=False):
+    def get_invocations(
+        self,
+        workflow_id: Optional[str] = None,
+        history_id: Optional[str] = None,
+        user_id: Optional[str] = None,
+        include_terminal: bool = True,
+        limit: Optional[int] = None,
+        view: str = "collection",
+        step_details: bool = False,
+    ) -> List[Dict[str, Any]]:
         """
         Get all workflow invocations, or select a subset by specifying optional
         arguments for filtering (e.g. a workflow ID).
@@ -69,22 +85,18 @@ class InvocationClient(Client):
               'uuid': 'c8aa2b1c-801a-11e5-a9e5-8ca98228593c',
               'workflow_id': '03501d7626bd192f'}]
         """
-        params = {
-            'include_terminal': include_terminal,
-            'view': view,
-            'step_details': step_details
-        }
+        params = {"include_terminal": include_terminal, "view": view, "step_details": step_details}
         if workflow_id:
-            params['workflow_id'] = workflow_id
+            params["workflow_id"] = workflow_id
         if history_id:
-            params['history_id'] = history_id
+            params["history_id"] = history_id
         if user_id:
-            params['user_id'] = user_id
+            params["user_id"] = user_id
         if limit is not None:
-            params['limit'] = limit
+            params["limit"] = limit
         return self._get(params=params)
 
-    def show_invocation(self, invocation_id):
+    def show_invocation(self, invocation_id: str) -> Dict[str, Any]:
         """
         Get a workflow invocation dictionary representing the scheduling of a
         workflow. This dictionary may be sparse at first (missing inputs and
@@ -132,11 +144,19 @@ class InvocationClient(Client):
         url = self._make_url(invocation_id)
         return self._get(url=url)
 
-    def rerun_invocation(self, invocation_id: str, inputs_update: Optional[dict] = None,
-                         params_update: Optional[dict] = None, history_id: Optional[str] = None,
-                         history_name: Optional[str] = None, import_inputs_to_history: bool = False,
-                         replacement_params: Optional[dict] = None, allow_tool_state_corrections: bool = False,
-                         inputs_by: Optional[str] = None, parameters_normalized: bool = False):
+    def rerun_invocation(
+        self,
+        invocation_id: str,
+        inputs_update: Optional[dict] = None,
+        params_update: Optional[dict] = None,
+        history_id: Optional[str] = None,
+        history_name: Optional[str] = None,
+        import_inputs_to_history: bool = False,
+        replacement_params: Optional[dict] = None,
+        allow_tool_state_corrections: bool = False,
+        inputs_by: Optional[InputsBy] = None,
+        parameters_normalized: bool = False,
+    ) -> Dict[str, Any]:
         """
         Rerun a workflow invocation. For more extensive documentation of all
         parameters, see the ``gi.workflows.invoke_workflow()`` method.
@@ -197,36 +217,36 @@ class InvocationClient(Client):
           This method works only on Galaxy 21.01 or later.
         """
         invocation_details = self.show_invocation(invocation_id)
-        workflow_id = invocation_details['workflow_id']
-        inputs = invocation_details['inputs']
-        wf_params = invocation_details['input_step_parameters']
+        workflow_id = invocation_details["workflow_id"]
+        inputs = invocation_details["inputs"]
+        wf_params = invocation_details["input_step_parameters"]
         if inputs_update:
             for inp, input_value in inputs_update.items():
                 inputs[inp] = input_value
         if params_update:
             for param, param_value in params_update.items():
                 wf_params[param] = param_value
-        payload = {'inputs': inputs, 'params': wf_params}
+        payload = {"inputs": inputs, "params": wf_params}
 
         if replacement_params:
-            payload['replacement_params'] = replacement_params
+            payload["replacement_params"] = replacement_params
         if history_id:
-            payload['history'] = f'hist_id={history_id}'
+            payload["history"] = f"hist_id={history_id}"
         elif history_name:
-            payload['history'] = history_name
+            payload["history"] = history_name
         if not import_inputs_to_history:
-            payload['no_add_to_history'] = True
+            payload["no_add_to_history"] = True
         if allow_tool_state_corrections:
-            payload['allow_tool_state_corrections'] = allow_tool_state_corrections
+            payload["allow_tool_state_corrections"] = allow_tool_state_corrections
         if inputs_by is not None:
-            payload['inputs_by'] = inputs_by
+            payload["inputs_by"] = inputs_by
         if parameters_normalized:
-            payload['parameters_normalized'] = parameters_normalized
-        api_params = {'instance': True}
-        url = '/'.join((self.gi.url, 'workflows', workflow_id, 'invocations'))
+            payload["parameters_normalized"] = parameters_normalized
+        api_params = {"instance": True}
+        url = "/".join((self.gi.url, "workflows", workflow_id, "invocations"))
         return self.gi.make_post_request(url=url, payload=payload, params=api_params)
 
-    def cancel_invocation(self, invocation_id):
+    def cancel_invocation(self, invocation_id: str) -> Dict[str, Any]:
         """
         Cancel the scheduling of a workflow.
 
@@ -239,7 +259,7 @@ class InvocationClient(Client):
         url = self._make_url(invocation_id)
         return self._delete(url=url)
 
-    def show_invocation_step(self, invocation_id, step_id):
+    def show_invocation_step(self, invocation_id: str, step_id: str) -> Dict[str, Any]:
         """
         See the details of a particular workflow invocation step.
 
@@ -267,8 +287,8 @@ class InvocationClient(Client):
         url = self._invocation_step_url(invocation_id, step_id)
         return self._get(url=url)
 
-    def run_invocation_step_action(self, invocation_id, step_id, action):
-        """ Execute an action for an active workflow invocation step. The
+    def run_invocation_step_action(self, invocation_id: str, step_id: str, action: Any) -> Dict[str, Any]:
+        """Execute an action for an active workflow invocation step. The
         nature of this action and what is expected will vary based on the
         the type of workflow step (the only currently valid action is True/False
         for pause steps).
@@ -290,7 +310,7 @@ class InvocationClient(Client):
         payload = {"action": action}
         return self._put(payload=payload, url=url)
 
-    def get_invocation_summary(self, invocation_id):
+    def get_invocation_summary(self, invocation_id: str) -> Dict[str, Any]:
         """
         Get a summary of an invocation, stating the number of jobs which
         succeed, which are paused and which have errored.
@@ -307,10 +327,10 @@ class InvocationClient(Client):
              'id': 'a799d38679e985db',
              'populated_state': 'ok'}
         """
-        url = self._make_url(invocation_id) + '/jobs_summary'
+        url = self._make_url(invocation_id) + "/jobs_summary"
         return self._get(url=url)
 
-    def get_invocation_step_jobs_summary(self, invocation_id):
+    def get_invocation_step_jobs_summary(self, invocation_id: str) -> List[Dict[str, Any]]:
         """
         Get a detailed summary of an invocation, listing all jobs with
         their job IDs and current states.
@@ -335,10 +355,10 @@ class InvocationClient(Client):
               'populated_state': 'ok',
               'states': {'new': 1}}]
         """
-        url = self._make_url(invocation_id) + '/step_jobs_summary'
+        url = self._make_url(invocation_id) + "/step_jobs_summary"
         return self._get(url=url)
 
-    def get_invocation_report(self, invocation_id):
+    def get_invocation_report(self, invocation_id: str) -> Dict[str, Any]:
         """
         Get a Markdown report for an invocation.
 
@@ -356,10 +376,10 @@ class InvocationClient(Client):
              'render_format': 'markdown',
              'workflows': {'f2db41e1fa331b3e': {'name': 'Example workflow'}}}
         """
-        url = self._make_url(invocation_id) + '/report'
+        url = self._make_url(invocation_id) + "/report"
         return self._get(url=url)
 
-    def get_invocation_report_pdf(self, invocation_id, file_path, chunk_size=CHUNK_SIZE):
+    def get_invocation_report_pdf(self, invocation_id: str, file_path: str, chunk_size: int = CHUNK_SIZE) -> None:
         """
         Get a PDF report for an invocation.
 
@@ -369,15 +389,17 @@ class InvocationClient(Client):
         :type file_path: str
         :param file_path: Path to save the report
         """
-        url = self._make_url(invocation_id) + '/report.pdf'
+        url = self._make_url(invocation_id) + "/report.pdf"
         r = self.gi.make_get_request(url, stream=True)
         if r.status_code != 200:
-            raise Exception("Failed to get the PDF report, the necessary dependencies may not be installed on the Galaxy server.")
-        with open(file_path, 'wb') as outf:
+            raise Exception(
+                "Failed to get the PDF report, the necessary dependencies may not be installed on the Galaxy server."
+            )
+        with open(file_path, "wb") as outf:
             for chunk in r.iter_content(chunk_size):
                 outf.write(chunk)
 
-    def get_invocation_biocompute_object(self, invocation_id):
+    def get_invocation_biocompute_object(self, invocation_id: str) -> Dict[str, Any]:
         """
         Get a BioCompute object for an invocation.
 
@@ -387,10 +409,12 @@ class InvocationClient(Client):
         :rtype: dict
         :return: The BioCompute object
         """
-        url = self._make_url(invocation_id) + '/biocompute'
+        url = self._make_url(invocation_id) + "/biocompute"
         return self._get(url=url)
 
-    def wait_for_invocation(self, invocation_id, maxwait=12000, interval=3, check=True):
+    def wait_for_invocation(
+        self, invocation_id: str, maxwait: float = 12000, interval: float = 3, check: bool = True
+    ) -> Dict[str, Any]:
         """
         Wait until an invocation is in a terminal state.
 
@@ -418,9 +442,9 @@ class InvocationClient(Client):
         time_left = maxwait
         while True:
             invocation = self.gi.invocations.show_invocation(invocation_id)
-            state = invocation['state']
+            state = invocation["state"]
             if state in INVOCATION_TERMINAL_STATES:
-                if check and state != 'scheduled':
+                if check and state != "scheduled":
                     raise Exception(f"Invocation {invocation_id} is in terminal state {state}")
                 return invocation
             if time_left > 0:
@@ -428,10 +452,12 @@ class InvocationClient(Client):
                 time.sleep(min(time_left, interval))
                 time_left -= interval
             else:
-                raise TimeoutException(f"Invocation {invocation_id} is still in non-terminal state {state} after {maxwait} s")
+                raise TimeoutException(
+                    f"Invocation {invocation_id} is still in non-terminal state {state} after {maxwait} s"
+                )
 
-    def _invocation_step_url(self, invocation_id, step_id):
-        return '/'.join((self._make_url(invocation_id), "steps", step_id))
+    def _invocation_step_url(self, invocation_id: str, step_id: str) -> str:
+        return "/".join((self._make_url(invocation_id), "steps", step_id))
 
 
-__all__ = ('InvocationClient',)
+__all__ = ("InvocationClient",)
