@@ -3,20 +3,27 @@ A representation of a Galaxy instance based on oo wrappers.
 """
 
 import time
+from typing import (
+    Iterable,
+    List,
+    Optional,
+)
 
 import bioblend
 import bioblend.galaxy
 from bioblend.galaxy.datasets import TERMINAL_STATES
-from . import client
+from . import (
+    client,
+    wrappers,
+)
 
 
-def _get_error_info(hda):
-    msg = hda.id
+def _get_error_info(dataset: wrappers.Dataset) -> str:
+    msg = dataset.id
     try:
-        msg += f" ({hda.name}): "
-        msg += hda.wrapped['misc_info']
+        msg += f" ({dataset.name}): {dataset.misc_info}"
     except Exception:  # avoid 'error while generating an error report'
-        msg += ': error'
+        msg += ": error"
     return msg
 
 
@@ -42,9 +49,19 @@ class GalaxyInstance:
       gi = GalaxyInstance('http://127.0.0.1:8080', 'foo')
       histories = gi.histories.list()
     """
-    def __init__(self, url, api_key=None, email=None, password=None, verify=True):
+
+    def __init__(
+        self,
+        url: str,
+        api_key: Optional[str] = None,
+        email: Optional[str] = None,
+        password: Optional[str] = None,
+        verify: bool = True,
+    ) -> None:
         self.gi = bioblend.galaxy.GalaxyInstance(url, api_key, email, password, verify)
         self.log = bioblend.log
+        self.datasets = client.ObjDatasetClient(self)
+        self.dataset_collections = client.ObjDatasetCollectionClient(self)
         self.histories = client.ObjHistoryClient(self)
         self.libraries = client.ObjLibraryClient(self)
         self.workflows = client.ObjWorkflowClient(self)
@@ -52,7 +69,9 @@ class GalaxyInstance:
         self.tools = client.ObjToolClient(self)
         self.jobs = client.ObjJobClient(self)
 
-    def _wait_datasets(self, datasets, polling_interval, break_on_error=True):
+    def _wait_datasets(
+        self, datasets: Iterable[wrappers.Dataset], polling_interval: float, break_on_error: bool = True
+    ) -> None:
         """
         Wait for datasets to come out of the pending states.
 
@@ -74,11 +93,12 @@ class GalaxyInstance:
           however, each input dataset is refreshed (possibly multiple
           times) during the execution.
         """
-        def poll(ds_list):
+
+        def poll(ds_list: Iterable[wrappers.Dataset]) -> List[wrappers.Dataset]:
             pending = []
             for ds in ds_list:
                 ds.refresh()
-                if break_on_error and ds.state == 'error':
+                if break_on_error and ds.state == "error":
                     raise RuntimeError(_get_error_info(ds))
                 if not ds.state:
                     self.log.warning("Dataset %s has an empty state", ds.id)
@@ -87,7 +107,7 @@ class GalaxyInstance:
                     pending.append(ds)
             return pending
 
-        self.log.info('Waiting for datasets')
+        self.log.info("Waiting for datasets")
         while datasets:
             datasets = poll(datasets)
             time.sleep(polling_interval)
