@@ -1,7 +1,6 @@
 """
 Contains possible interaction dealing with Galaxy tools.
 """
-import warnings
 from os.path import basename
 from typing import (
     Any,
@@ -37,13 +36,6 @@ class ToolClient(Client):
         Get all tools, or select a subset by specifying optional arguments for
         filtering (e.g. a tool name).
 
-        :type tool_id: str
-        :param tool_id: id of the requested tool
-
-          .. deprecated:: 0.16.0
-             To get details of a tool for which you know the ID, use the much
-             more efficient :meth:`show_tool` instead.
-
         :type name: str
         :param name: Tool name to filter on.
 
@@ -55,19 +47,17 @@ class ToolClient(Client):
         :return: List of tool descriptions.
 
         .. seealso:: bioblend.galaxy.toolshed.get_repositories()
+
+        .. versionchanged:: 1.1.1
+           Using the deprecated ``tool_id`` parameter now raises a
+           ``ValueError`` exception.
         """
         if tool_id is not None:
-            warnings.warn(
-                "The tool_id parameter is deprecated, use the show_tool() method to view details of a tool for which you know the ID.",
-                category=FutureWarning,
+            raise ValueError(
+                "The tool_id parameter has been removed, use the show_tool() method to view details of a tool for which you know the ID."
             )
-        if tool_id is not None and name is not None:
-            raise ValueError("Provide only one argument between name or tool_id, but not both")
         tools = self._raw_get_tool(in_panel=False, trackster=trackster)
-        if tool_id is not None:
-            tool = next((_ for _ in tools if _["id"] == tool_id), None)
-            tools = [tool] if tool is not None else []
-        elif name is not None:
+        if name is not None:
             tools = [_ for _ in tools if _["name"] == name]
         return tools
 
@@ -343,8 +333,8 @@ class ToolClient(Client):
         tool_id: str,
         tool_inputs: Union[InputsBuilder, dict],
         input_format: Literal["21.01", "legacy"] = "legacy",
+        data_manager_mode: Optional[Literal["populate", "dry_run", "bundle"]] = None,
     ) -> Dict[str, Any]:
-
         """
         Runs tool specified by ``tool_id`` in history indicated
         by ``history_id`` with inputs from ``dict`` ``tool_inputs``.
@@ -355,6 +345,16 @@ class ToolClient(Client):
         :type tool_id: str
         :param tool_id: ID of the tool to be run
 
+        :type data_manager_mode: str
+        :param data_manager_mode: Possible values are 'populate', 'dry_run' and 'bundle'.
+
+          'populate' is the default behavior for data manager tools and results in tool data table
+          files being updated after the data manager job completes.
+
+          'dry_run' will skip any processing after the data manager job completes
+
+          'bundle' will create a data manager bundle that can be imported on other Galaxy servers.
+
         :type tool_inputs: dict
         :param tool_inputs: dictionary of input datasets and parameters
           for the tool (see below)
@@ -427,6 +427,10 @@ class ToolClient(Client):
             payload["inputs"] = tool_inputs.to_dict()
         else:
             payload["inputs"] = tool_inputs
+
+        if data_manager_mode:
+            payload["data_manager_mode"] = data_manager_mode
+
         return self._post(payload)
 
     def upload_file(
