@@ -11,6 +11,7 @@ from typing import (
     TYPE_CHECKING,
 )
 
+from bioblend import ConnectionError
 from bioblend.galaxy.client import Client
 
 if TYPE_CHECKING:
@@ -201,8 +202,17 @@ class UserClient(Client):
         :return: the API key for the user, or 'Not available.' if it doesn't
           exist yet.
         """
-        url = self._make_url(user_id) + "/api_key/inputs"
-        return self._get(url=url)["inputs"][0]["value"]
+        try:
+            url = self._make_url(user_id) + "/api_key/detailed"
+            return self._get(url=url)["key"]
+        except ConnectionError as e:
+            if e.status_code == 204:
+                return "Not available."
+            elif e.status_code != 404:
+                raise
+            # Galaxy 22.05 or earlier
+            url = self._make_url(user_id) + "/api_key/inputs"
+            return self._get(url=url)["inputs"][0]["value"]
 
     def get_or_create_user_apikey(self, user_id: str) -> str:
         """
@@ -221,14 +231,20 @@ class UserClient(Client):
         url = self._make_url(user_id) + "/api_key"
         return self._get(url=url)
 
-    def update_user(self, user_id: str, **kwargs: Any) -> Dict[str, Any]:
+    def update_user(self, user_id: str, user_data: Optional[Dict] = None, **kwargs: Any) -> Dict[str, Any]:
         """
-        Update user information. Some of the attributes that can be
-        modified are documented below.
+        Update user information. You can either pass the attributes you want to
+        change in the user_data dictionary, or provide them separately as
+        keyword arguments.
+        For attributes that cannot be expressed as keywords (e.g.
+        extra_user_preferences use a `|` sign), pass them in user_data.
 
         :type user_id: str
         :param user_id: encoded user ID
 
+        :type user_data: dict
+        :param user_data: a dict containing the values to be updated, eg. { "username" : "newUsername", "email": "new@email" }
+
         :type username: str
         :param username: Replace user name with the given string
 
@@ -238,5 +254,8 @@ class UserClient(Client):
         :rtype: dict
         :return: details of the updated user
         """
+        if user_data is None:
+            user_data = {}
+        user_data.update(kwargs)
         url = self._make_url(user_id) + "/information/inputs"
-        return self._put(url=url, payload=kwargs, id=user_id)
+        return self._put(url=url, payload=user_data, id=user_id)
