@@ -1,12 +1,25 @@
 """
 A base representation of an instance of Tool Shed
 """
+from typing import Optional
+
 from bioblend.galaxyclient import GalaxyClient
-from bioblend.toolshed import categories, repositories, tools
+from bioblend.toolshed import (
+    categories,
+    repositories,
+    tools,
+)
 
 
 class ToolShedInstance(GalaxyClient):
-    def __init__(self, url, key=None, email=None, password=None, verify=True):
+    def __init__(
+        self,
+        url: str,
+        key: Optional[str] = None,
+        email: Optional[str] = None,
+        password: Optional[str] = None,
+        verify: bool = True,
+    ) -> None:
         """
         A base representation of a connection to a ToolShed instance, identified
         by the ToolShed URL and user credentials.
