@@ -1,19 +1,40 @@
 """
 Interaction with a Tool Shed instance repositories
 """
+from typing import (
+    Any,
+    Dict,
+    List,
+    Optional,
+    TYPE_CHECKING,
+    Union,
+)
+
+from typing_extensions import Literal
+
 from bioblend.galaxy.client import Client
 from bioblend.util import attach_file
 
+if TYPE_CHECKING:
+    from bioblend.toolshed import ToolShedInstance
+
 
 class ToolShedRepositoryClient(Client):
-    module = 'repositories'
+    module = "repositories"
 
-    def __init__(self, toolshed_instance):
+    def __init__(self, toolshed_instance: "ToolShedInstance") -> None:
         super().__init__(toolshed_instance)
 
-    def get_repositories(self):
+    def get_repositories(self, name: Optional[str] = None, owner: Optional[str] = None) -> List[Dict[str, Any]]:
         """
-        Get a list of all the repositories in a Galaxy Tool Shed.
+        Get all repositories in a Galaxy Tool Shed, or select a subset by
+        specifying optional arguments for filtering (e.g. a repository name).
+
+        :type name: str
+        :param name: Repository name to filter on.
+
+        :type owner: str
+        :param owner: Repository owner to filter on.
 
         :rtype: list
         :return: Returns a list of dictionaries containing information about
@@ -21,27 +42,38 @@ class ToolShedRepositoryClient(Client):
           For example::
 
             [{'category_ids': ['c1df3132f6334b0e', 'f6d7b0037d901d9b'],
+              'create_time': '2020-02-09T16:24:37.098176',
               'deleted': False,
               'deprecated': False,
               'description': 'Order Contigs',
               'homepage_url': '',
               'id': '287bd69f724b99ce',
+              'model_class': 'Repository',
               'name': 'best_tool_ever',
               'owner': 'billybob',
               'private': False,
               'remote_repository_url': '',
               'times_downloaded': 0,
               'type': 'unrestricted',
-              'url': '/api/repositories/287bd69f724b99ce',
               'user_id': '5cefd48bc04af6d4'}]
 
         .. versionchanged:: 0.4.1
           Changed method name from ``get_tools`` to ``get_repositories`` to
           better align with the Tool Shed concepts.
         """
-        return self._get()
+        params = {}
+        if name:
+            params["name"] = name
+        if owner:
+            params["owner"] = owner
+        return self._get(params=params)
 
-    def search_repositories(self, q, page=1, page_size=10):
+    def search_repositories(
+        self,
+        q: str,
+        page: int = 1,
+        page_size: int = 10,
+    ) -> Dict[str, Any]:
         """
         Search for repositories in a Galaxy Tool Shed.
 
@@ -61,6 +93,7 @@ class ToolShedRepositoryClient(Client):
 
             {'hits': [{'matched_terms': [],
                        'repository': {'approved': 'no',
+                                      'categories': 'fastq manipulation',
                                       'description': 'Convert export file to fastq',
                                       'full_last_updated': '2015-01-18 09:48 AM',
                                       'homepage_url': '',
@@ -69,11 +102,13 @@ class ToolShedRepositoryClient(Client):
                                       'long_description': 'This is a simple too to convert Solexas Export files to FASTQ files.',
                                       'name': 'export_to_fastq',
                                       'remote_repository_url': '',
+                                      'repo_lineage': "['0:c9e926d9d87e', '1:38859774da87']"
                                       'repo_owner_username': 'louise',
                                       'times_downloaded': 164},
                        'score': 4.92},
                       {'matched_terms': [],
                        'repository': {'approved': 'no',
+                                      'categories': 'fastq manipulation',
                                       'description': 'Convert BAM file to fastq',
                                       'full_last_updated': '2015-04-07 11:57 AM',
                                       'homepage_url': '',
@@ -82,6 +117,7 @@ class ToolShedRepositoryClient(Client):
                                       'long_description': 'Use Picards SamToFastq to convert a BAM file to fastq. Useful for storing reads as BAM in Galaxy and converting to fastq when needed for analysis.',
                                       'name': 'bam_to_fastq',
                                       'remote_repository_url': '',
+                                      'repo_lineage': "['0:a0af255e28c1', '1:2523cb0fb84c', '2:2656247b5253']"
                                       'repo_owner_username': 'brad-chapman',
                                       'times_downloaded': 138},
                        'score': 4.14}],
@@ -93,7 +129,10 @@ class ToolShedRepositoryClient(Client):
         params = dict(q=q, page=page, page_size=page_size)
         return self._get(params=params)
 
-    def show_repository(self, toolShed_id):
+    def show_repository(
+        self,
+        toolShed_id: str,
+    ) -> Dict[str, Any]:
         """
         Display information of a repository from Tool Shed
 
@@ -105,19 +144,20 @@ class ToolShedRepositoryClient(Client):
           For example::
 
             {'category_ids': ['c1df3132f6334b0e', 'f6d7b0037d901d9b'],
+             'create_time': '2020-02-22T20:39:15.548491',
              'deleted': False,
              'deprecated': False,
              'description': 'Order Contigs',
              'homepage_url': '',
              'id': '287bd69f724b99ce',
              'long_description': '',
+             'model_class': 'Repository',
              'name': 'best_tool_ever',
              'owner': 'billybob',
              'private': False,
              'remote_repository_url': '',
              'times_downloaded': 0,
              'type': 'unrestricted',
-             'url': '/api/repositories/287bd69f724b99ce',
              'user_id': '5cefd48bc04af6d4'}
 
         .. versionchanged:: 0.4.1
@@ -126,7 +166,11 @@ class ToolShedRepositoryClient(Client):
         """
         return self._get(id=toolShed_id)
 
-    def get_ordered_installable_revisions(self, name, owner):
+    def get_ordered_installable_revisions(
+        self,
+        name: str,
+        owner: str,
+    ) -> List[str]:
         """
         Returns the ordered list of changeset revision hash strings that are
         associated with installable revisions. As in the changelog, the list is
@@ -141,17 +185,18 @@ class ToolShedRepositoryClient(Client):
         :rtype: list
         :return: List of changeset revision hash strings from oldest to newest
         """
-        url = self._make_url() + '/get_ordered_installable_revisions'
-        params = {
-            'name': name,
-            'owner': owner
-        }
+        url = self._make_url() + "/get_ordered_installable_revisions"
+        params = {"name": name, "owner": owner}
         r = self._get(url=url, params=params)
 
         return r
 
-    def get_repository_revision_install_info(self, name, owner,
-                                             changeset_revision):
+    def get_repository_revision_install_info(
+        self,
+        name: str,
+        owner: str,
+        changeset_revision: str,
+    ) -> List[Dict[str, Any]]:
         """
         Return a list of dictionaries of metadata about a certain changeset
         revision for a single tool.
@@ -176,12 +221,14 @@ class ToolShedRepositoryClient(Client):
 
           For example::
 
-            [{'deleted': False,
+            [{'create_time': '2020-08-20T13:17:08.818518',
+              'deleted': False,
               'deprecated': False,
               'description': 'Galaxy Freebayes Bayesian genetic variant detector tool',
               'homepage_url': '',
               'id': '491b7a3fddf9366f',
               'long_description': 'Galaxy Freebayes Bayesian genetic variant detector tool originally included in the Galaxy code distribution but migrated to the tool shed.',
+              'model_class': 'Repository',
               'name': 'freebayes',
               'owner': 'devteam',
               'private': False,
@@ -201,8 +248,34 @@ class ToolShedRepositoryClient(Client):
               'includes_tools_for_display_in_tool_panel': True,
               'includes_workflows': False,
               'malicious': False,
+              'missing_test_components': False,
+              'model_class': 'RepositoryMetadata',
+              'numeric_revision': 0,
               'repository_id': '491b7a3fddf9366f',
               'url': '/api/repository_revisions/504be8aaa652c154'},
+              'valid_tools': [{'add_to_tool_panel': True,
+                'description': '- Bayesian genetic variant detector',
+                'guid': 'testtoolshed.g2.bx.psu.edu/repos/devteam/freebayes/freebayes/0.0.3',
+                'id': 'freebayes',
+                'name': 'FreeBayes',
+                'requirements': [{'name': 'freebayes',
+                  'type': 'package',
+                  'version': '0.9.6_9608597d12e127c847ae03aa03440ab63992fedf'},
+                {'name': 'samtools', 'type': 'package', 'version': '0.1.18'}],
+                'tests': [{'inputs': [['reference_source|reference_source_selector',
+                    'history'],
+                  ['options_type|options_type_selector', 'basic'],
+                  ['reference_source|ref_file', 'phiX.fasta'],
+                  ['reference_source|input_bams_0|input_bam', 'fake_phiX_reads_1.bam']],
+                  'name': 'Test-1',
+                  'outputs': [['output_vcf', 'freebayes_out_1.vcf.contains']],
+                  'required_files': ['fake_phiX_reads_1.bam',
+                  'phiX.fasta',
+                  'freebayes_out_1.vcf.contains']}],
+                'tool_config': '/srv/toolshed/test/var/data/repos/000/repo_708/freebayes.xml',
+                'tool_type': 'default',
+                'version': '0.0.3',
+                'version_string_cmd': None}]},
              {'freebayes': ['Galaxy Freebayes Bayesian genetic variant detector tool',
                             'http://testtoolshed.g2.bx.psu.edu/repos/devteam/freebayes',
                             'd291dc763c4c',
@@ -222,19 +295,17 @@ class ToolShedRepositoryClient(Client):
                                                  'type': 'package',
                                                  'version': '0.1.18'}}]}]
         """
-        url = self._make_url() + '/get_repository_revision_install_info'
-        params = {
-            'name': name,
-            'owner': owner,
-            'changeset_revision': changeset_revision
-        }
+        url = self._make_url() + "/get_repository_revision_install_info"
+        params = {"name": name, "owner": owner, "changeset_revision": changeset_revision}
         return self._get(url=url, params=params)
 
-    def repository_revisions(self, downloadable=None, malicious=None,
-                             tools_functionally_correct=None,
-                             missing_test_components=None, do_not_test=None,
-                             includes_tools=None, test_install_error=None,
-                             skip_tool_test=None):
+    def repository_revisions(
+        self,
+        downloadable: Optional[bool] = None,
+        malicious: Optional[bool] = None,
+        missing_test_components: Optional[bool] = None,
+        includes_tools: Optional[bool] = None,
+    ) -> List[Dict[str, Any]]:
         """
         Returns a (possibly filtered) list of dictionaries that include
         information about all repository revisions. The following parameters can
@@ -246,31 +317,18 @@ class ToolShedRepositoryClient(Client):
         :type malicious: bool
         :param malicious:
 
-        :type tools_functionally_correct: bool
-        :param tools_functionally_correct:
-
         :type missing_test_components: bool
         :param missing_test_components:
 
-        :type do_not_test: bool
-        :param do_not_test:
-
         :type includes_tools: bool
         :param includes_tools:
 
-        :type test_install_error: bool
-        :param test_install_error:
-
-        :type skip_tool_test: bool
-        :param skip_tool_test:
-
         :rtype: List of dictionaries
         :return: Returns a (possibly filtered) list of dictionaries that include
           information about all repository revisions.
           For example::
 
             [{'changeset_revision': '6e26c5a48e9a',
-              'do_not_test': False,
               'downloadable': True,
               'has_repository_dependencies': False,
               'id': '92250afff777a169',
@@ -281,13 +339,11 @@ class ToolShedRepositoryClient(Client):
               'includes_workflows': False,
               'malicious': False,
               'missing_test_components': False,
+              'model_class': 'RepositoryMetadata',
+              'numeric_revision': None,
               'repository_id': '78f2604ff5e65707',
-              'test_install_error': False,
-              'time_last_tested': None,
-              'tools_functionally_correct': False,
               'url': '/api/repository_revisions/92250afff777a169'},
              {'changeset_revision': '15a54fa11ad7',
-              'do_not_test': False,
               'downloadable': True,
               'has_repository_dependencies': False,
               'id': 'd3823c748ae2205d',
@@ -298,36 +354,30 @@ class ToolShedRepositoryClient(Client):
               'includes_workflows': False,
               'malicious': False,
               'missing_test_components': False,
+              'model_class': 'RepositoryMetadata',
+              'numeric_revision': None,
               'repository_id': 'f9662009da7bfce0',
-              'test_install_error': False,
-              'time_last_tested': None,
-              'tools_functionally_correct': False,
               'url': '/api/repository_revisions/d3823c748ae2205d'}]
         """
         # Not using '_make_url' or '_get' to create url since the module id used
         # to create url is not the same as needed for this method
-        url = self.gi.url + '/repository_revisions'
+        url = self.gi.url + "/repository_revisions"
         params = {}
-        if downloadable:
-            params['downloadable'] = True
-        if malicious:
-            params['malicious'] = True
-        if tools_functionally_correct:
-            params['tools_functionally_correct'] = True
-        if missing_test_components:
-            params['missing_test_components'] = True
-        if do_not_test:
-            params['do_not_test'] = True
-        if includes_tools:
-            params['includes_tools'] = True
-        if test_install_error:
-            params['test_install_error'] = True
-        if skip_tool_test:
-            params['skip_tool_test'] = True
+        if downloadable is not None:
+            params["downloadable"] = downloadable
+        if malicious is not None:
+            params["malicious"] = malicious
+        if missing_test_components is not None:
+            params["missing_test_components"] = missing_test_components
+        if includes_tools is not None:
+            params["includes_tools"] = includes_tools
         return self._get(url=url, params=params)
 
-    def show_repository_revision(self, metadata_id):
-        '''
+    def show_repository_revision(
+        self,
+        metadata_id: str,
+    ) -> Dict[str, Any]:
+        """
         Returns a dictionary that includes information about a specified
         repository revision.
 
@@ -340,7 +390,6 @@ class ToolShedRepositoryClient(Client):
           For example::
 
             {'changeset_revision': '7602de1e7f32',
-             'do_not_test': False,
              'downloadable': True,
              'has_repository_dependencies': False,
              'id': '504be8aaa652c154',
@@ -351,20 +400,19 @@ class ToolShedRepositoryClient(Client):
              'includes_workflows': False,
              'malicious': False,
              'missing_test_components': True,
+             'model_class': 'RepositoryMetadata',
+             'numeric_revision': None,
+             'repository_dependencies': [],
              'repository_id': '491b7a3fddf9366f',
-             'test_install_error': False,
-             'time_last_tested': None,
-             'tool_test_results': {'missing_test_components': []},
-             'tools_functionally_correct': False,
              'url': '/api/repository_revisions/504be8aaa652c154'}
-        '''
+        """
         # Not using '_make_url' or '_get' to create url since the module id used
         # to create url is not the same as needed for this method
         # since metadata_id has to be defined, easy to create the url here
-        url = '/'.join((self.gi.url, 'repository_revisions', metadata_id))
+        url = "/".join((self.gi.url, "repository_revisions", metadata_id))
         return self._get(url=url)
 
-    def update_repository(self, id, tar_ball_path, commit_message=None):
+    def update_repository(self, id: str, tar_ball_path: str, commit_message: Optional[str] = None) -> Dict[str, Any]:
         """
         Update the contents of a Tool Shed repository with specified tar ball.
 
@@ -389,20 +437,25 @@ class ToolShedRepositoryClient(Client):
 
         .. versionadded:: 0.5.2
         """
-        url = self._make_url(id) + '/changeset_revision'
-        payload = {
-            'file': attach_file(tar_ball_path)
-        }
+        url = self._make_url(id) + "/changeset_revision"
+        payload: Dict[str, Any] = {"file": attach_file(tar_ball_path)}
         if commit_message is not None:
-            payload['commit_message'] = commit_message
+            payload["commit_message"] = commit_message
         try:
             return self._post(payload=payload, files_attached=True, url=url)
         finally:
-            payload['file'].close()
+            payload["file"].close()
 
-    def create_repository(self, name, synopsis, description=None,
-                          type='unrestricted', remote_repository_url=None,
-                          homepage_url=None, category_ids=None):
+    def create_repository(
+        self,
+        name: str,
+        synopsis: str,
+        description: Optional[str] = None,
+        type: Literal["unrestricted", "repository_suite_definition", "tool_dependency_definition"] = "unrestricted",
+        remote_repository_url: Optional[str] = None,
+        homepage_url: Optional[str] = None,
+        category_ids: Optional[List[str]] = None,
+    ) -> Dict[str, Any]:
         """
         Create a new repository in a Tool Shed.
 
@@ -448,20 +501,73 @@ class ToolShedRepositoryClient(Client):
              "type": "unrestricted",
              "user_id": "adb5f5c93f827949"}
         """
-        payload = {
-            'name': name,
-            'synopsis': synopsis,
+        payload: Dict[str, Union[str, List[str]]] = {
+            "name": name,
+            "synopsis": synopsis,
         }
         if description is not None:
-            payload['description'] = description
+            payload["description"] = description
         if description is not None:
-            payload['description'] = description
+            payload["description"] = description
         if type is not None:
-            payload['type'] = type
+            payload["type"] = type
         if remote_repository_url is not None:
-            payload['remote_repository_url'] = remote_repository_url
+            payload["remote_repository_url"] = remote_repository_url
         if homepage_url is not None:
-            payload['homepage_url'] = homepage_url
+            payload["homepage_url"] = homepage_url
         if category_ids is not None:
-            payload['category_ids[]'] = category_ids
+            payload["category_ids[]"] = category_ids
         return self._post(payload)
+
+    def update_repository_metadata(
+        self,
+        toolShed_id: str,
+        name: Optional[str] = None,
+        synopsis: Optional[str] = None,
+        description: Optional[str] = None,
+        remote_repository_url: Optional[str] = None,
+        homepage_url: Optional[str] = None,
+        category_ids: Optional[List[str]] = None,
+    ) -> Dict[str, Any]:
+        """
+        Update metadata of a Tool Shed repository.
+
+        :type toolShed_id: str
+        :param name: ID of the repository to update
+
+        :type name: str
+        :param name: New name of the repository
+
+        :type synopsis: str
+        :param synopsis: New synopsis of the repository
+
+        :type description: str
+        :param description: New description of the repository
+
+        :type remote_repository_url: str
+        :param remote_repository_url: New remote URL (e.g. GitHub/Bitbucket
+          repository)
+
+        :type homepage_url: str
+        :param homepage_url: New upstream homepage for the project
+
+        :type category_ids: list
+        :param category_ids: New list of encoded category IDs
+
+        :rtype: dict
+        :return: a dictionary containing information about the updated repository.
+        """
+        payload: Dict[str, Union[str, List[str]]] = {}
+        if name:
+            payload["name"] = name
+        if synopsis:
+            payload["synopsis"] = synopsis
+        if description:
+            payload["description"] = description
+        if remote_repository_url:
+            payload["remote_repository_url"] = remote_repository_url
+        if homepage_url:
+            payload["homepage_url"] = homepage_url
+        if category_ids:
+            payload["category_ids"] = category_ids
+        return self._put(id=toolShed_id, payload=payload)
