@@ -1,16 +1,26 @@
 """
 Interaction with a Tool Shed instance tools
 """
+from typing import (
+    Any,
+    Dict,
+    TYPE_CHECKING,
+)
+
 from bioblend.galaxy.client import Client
 
+if TYPE_CHECKING:
+    from bioblend.toolshed import ToolShedInstance
+
 
 class ToolShedToolClient(Client):
-    module = 'tools'
+    gi: "ToolShedInstance"
+    module = "tools"
 
-    def __init__(self, toolshed_instance):
+    def __init__(self, toolshed_instance: "ToolShedInstance") -> None:
         super().__init__(toolshed_instance)
 
-    def search_tools(self, q, page=1, page_size=10):
+    def search_tools(self, q: str, page: int = 1, page_size: int = 10) -> Dict[str, Any]:
         """
         Search for tools in a Galaxy Tool Shed.
 
@@ -46,5 +56,5 @@ class ToolShedToolClient(Client):
              'page_size': '2',
              'total_results': '118'}
         """
-        params = dict(q=q, page=page, page_size=page_size)
+        params = {"q": q, "page": page, "page_size": page_size}
         return self._get(params=params)
