@@ -3,7 +3,7 @@ This example retrieves details of all the Data Libraries available to us and lis
 
 Usage: python list_data_libraries.py <Galaxy_URL> <Galaxy_API_key>
 """
-from __future__ import print_function
+
 import sys
 
 from bioblend.galaxy.objects import GalaxyInstance
@@ -27,4 +27,4 @@ if len(libraries) == 0:
 else:
     print("\nData Libraries:")
     for lib in libraries:
-        print("{0} : {1}".format(lib.name, lib.id))
+        print(f"{lib.name} : {lib.id}")
